@@ -80,7 +80,7 @@ def get_metadata_from_archive(f, extension, extract_fn, member="PKG-INFO"):
     except KeyError:
         try:
             name, version = prefix.rsplit("-", 1)
-        except ValueError as e:
+        except ValueError:
             raise Exception("unable to extract metadata")
         return Metadata(name, normalize(name), version, "")
     return parse_pkg_metadata(metadata)
@@ -189,6 +189,7 @@ def download(
     python_version=None,
     implementation=None,
     abi=None,
+    no_build_isolation=None,
     pip="pip",
 ):
     args = [pip, "download", "-d", dest]
@@ -201,13 +202,17 @@ def download(
     if platform or python_version or implementation or abi:
         args += ["--only-binary", ":all:"]
     if platform:
-        args += ["--platform", platform]
+        for p in platform:
+            args += ["--platform", p]
     if python_version:
         args += ["--python-version", python_version]
     if implementation:
         args += ["--implementation", implementation]
     if abi:
-        args += ["--abi", abi]
+        for a in abi:
+            args += ["--abi", a]
+    if no_build_isolation:
+        args += ["--no-build-isolation"]
     for r in requirements:
         args += ["-r", r]
     args += pkgs
@@ -461,6 +466,7 @@ class DownloadCmd(DownloadDirCmd):
         )
         parser.add_argument(
             "--platform",
+            action="append",
             metavar="PLATFORM",
             help="only download wheels compatible with %(metavar)s. "
             "This option implies --binary.",
@@ -479,10 +485,19 @@ class DownloadCmd(DownloadDirCmd):
         )
         parser.add_argument(
             "--abi",
+            action="append",
             metavar="ABI",
             help="only download wheels compatible with Python "
             "abi %(metavar)s. This option implies --binary.",
         )
+        parser.add_argument(
+            "--no-build-isolation",
+            action="store_true",
+            help="Disable isolation when building a modern source "
+            "distribution. Build dependencies specified by "
+            "PEP 518 must be already installed if this option "
+            "is used.",
+        )
         parser.add_argument(
             "-r",
             "--requirement",
@@ -509,6 +524,7 @@ class DownloadCmd(DownloadDirCmd):
             python_version=args.python_version,
             implementation=args.implementation,
             abi=args.abi,
+            no_build_isolation=args.no_build_isolation,
             pip=args.pip_executable,
         )
         pkgs = args.pkg
